{
  config,
  lib,
  pkgs,
  ...
}: {
  home.packages = with pkgs; [
    # Rust rewrites of cli stuff
    fd
    sd
    du-dust
    ripgrep
    ripgrep-all
    hyperfine
    dogdns
    duf
    xcp
    # Man but terse
    tealdeer
    # rsync
    rclone
    # General
    file
    tokei
    gping
    # Spell check
    hunspell
    hunspellDicts.en-us
    # Cli markdown renderer
    glow
    # Better curl
    httpie
    # go with jq
    jc
    fx
    # jq, but for html/xml
    xq-xml
    # unzip
    unzip
  ];
  programs.tmux = {
    enable = true;
    aggressiveResize = true;
    keyMode = "vi";
    shortcut = "x";
    terminal =
      if pkgs.stdenv.isLinux
      then "tmux-256color"
      else "screen-256color";
    escapeTime = 100;
    plugins = with pkgs; [
      tmuxPlugins.cpu
      tmuxPlugins.jump
    ];
    extraConfig = ''
      set -ag terminal-overrides ",xterm-256color:RGB"
      set-option -g status-interval 1
      set-option -g automatic-rename on
      set-option -g automatic-rename-format '#{b:pane_current_path}: #{pane_current_command}'
    '';
  };
  programs.btop.enable = true;
  programs.jq.enable = true;
}
